@@ -6,31 +6,29 @@
 #include "database.h"
 #include "debug.h"
 
-static int assert_init(
-	semanage_handle_t* handle, 
-	dbase_config_t* dconfig) {
+static int assert_init(semanage_handle_t * handle, dbase_config_t * dconfig)
+{
 
 	if (dconfig->dtable == NULL) {
-		
+
 		ERR(handle,
-			"A direct or server connection is needed "
-			"to use this function - please call "
-			"the corresponding connect() method");
+		    "A direct or server connection is needed "
+		    "to use this function - please call "
+		    "the corresponding connect() method");
 		return STATUS_ERR;
 	}
 
 	return STATUS_SUCCESS;
 }
 
-static int enter_ro(
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig) {
+static int enter_ro(semanage_handle_t * handle, dbase_config_t * dconfig)
+{
 
 	if (assert_init(handle, dconfig) < 0)
 		goto err;
 
 	if (!handle->is_in_transaction &&
-	     handle->conf->store_type == SEMANAGE_CON_DIRECT) {
+	    handle->conf->store_type == SEMANAGE_CON_DIRECT) {
 
 		if (semanage_get_active_lock(handle) < 0) {
 			ERR(handle, "could not get the active lock");
@@ -43,27 +41,25 @@ static int enter_ro(
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not enter read-only section");
 	return STATUS_ERR;
 }
 
-static inline int exit_ro(
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig) {
+static inline int exit_ro(semanage_handle_t * handle, dbase_config_t * dconfig)
+{
 
-	int commit_num = handle->funcs->get_serial(handle); 
+	int commit_num = handle->funcs->get_serial(handle);
 
-	if (!handle->is_in_transaction && 
-	     handle->conf->store_type == SEMANAGE_CON_DIRECT) 
+	if (!handle->is_in_transaction &&
+	    handle->conf->store_type == SEMANAGE_CON_DIRECT)
 		semanage_release_active_lock(handle);
 
 	return commit_num;
 }
 
-static int enter_rw(
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig) {
+static int enter_rw(semanage_handle_t * handle, dbase_config_t * dconfig)
+{
 
 	if (assert_init(handle, dconfig) < 0)
 		goto err;
@@ -78,16 +74,15 @@ static int enter_rw(
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not enter read-write section");
 	return STATUS_ERR;
 }
 
-int dbase_modify (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	const record_key_t* key,
-	const record_t* data) {
+int dbase_modify(semanage_handle_t * handle,
+		 dbase_config_t * dconfig,
+		 const record_key_t * key, const record_t * data)
+{
 
 	if (enter_rw(handle, dconfig) < 0)
 		return STATUS_ERR;
@@ -98,11 +93,10 @@ int dbase_modify (
 	return STATUS_SUCCESS;
 }
 
-int dbase_set (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	const record_key_t* key,
-	const record_t* data) {
+int dbase_set(semanage_handle_t * handle,
+	      dbase_config_t * dconfig,
+	      const record_key_t * key, const record_t * data)
+{
 
 	if (enter_rw(handle, dconfig) < 0)
 		return STATUS_ERR;
@@ -113,10 +107,9 @@ int dbase_set (
 	return STATUS_SUCCESS;
 }
 
-int dbase_del (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	const record_key_t* key) {
+int dbase_del(semanage_handle_t * handle,
+	      dbase_config_t * dconfig, const record_key_t * key)
+{
 
 	if (enter_rw(handle, dconfig) < 0)
 		return STATUS_ERR;
@@ -127,11 +120,10 @@ int dbase_del (
 	return STATUS_SUCCESS;
 }
 
-int dbase_query (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	const record_key_t* key,
-	record_t** response) {
+int dbase_query(semanage_handle_t * handle,
+		dbase_config_t * dconfig,
+		const record_key_t * key, record_t ** response)
+{
 
 	if (enter_ro(handle, dconfig) < 0)
 		return STATUS_ERR;
@@ -144,11 +136,10 @@ int dbase_query (
 	return exit_ro(handle, dconfig);
 }
 
-int dbase_exists (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	const record_key_t* key,
-	int* response) {
+int dbase_exists(semanage_handle_t * handle,
+		 dbase_config_t * dconfig,
+		 const record_key_t * key, int *response)
+{
 
 	if (enter_ro(handle, dconfig) < 0)
 		return STATUS_ERR;
@@ -161,29 +152,26 @@ int dbase_exists (
 	return exit_ro(handle, dconfig);
 }
 
-int dbase_count (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	unsigned int* response) {
+int dbase_count(semanage_handle_t * handle,
+		dbase_config_t * dconfig, unsigned int *response)
+{
 
 	if (enter_ro(handle, dconfig) < 0)
 		return STATUS_ERR;
 
 	if (dconfig->dtable->count(handle, dconfig->dbase, response) < 0) {
-		exit_ro(handle, dconfig);	
+		exit_ro(handle, dconfig);
 		return STATUS_ERR;
 	}
 
 	return exit_ro(handle, dconfig);
 }
 
-int dbase_iterate(
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	int (*fn) (
-		const record_t* record, 
-		void* fn_arg),
-	void* fn_arg) {
+int dbase_iterate(semanage_handle_t * handle,
+		  dbase_config_t * dconfig,
+		  int (*fn) (const record_t * record,
+			     void *fn_arg), void *fn_arg)
+{
 
 	if (enter_ro(handle, dconfig) < 0)
 		return STATUS_ERR;
@@ -196,17 +184,16 @@ int dbase_iterate(
 	return exit_ro(handle, dconfig);
 }
 
-int dbase_list (
-	semanage_handle_t* handle,
-	dbase_config_t* dconfig,
-	record_t*** records,
-	unsigned int* count) {
+int dbase_list(semanage_handle_t * handle,
+	       dbase_config_t * dconfig,
+	       record_t *** records, unsigned int *count)
+{
 
 	if (enter_ro(handle, dconfig) < 0)
 		return STATUS_ERR;
 
 	if (dconfig->dtable->list(handle, dconfig->dbase, records, count) < 0) {
-		exit_ro(handle, dconfig);	
+		exit_ro(handle, dconfig);
 		return STATUS_ERR;
 	}
 
